"""
demal

MAL (Meta Attack Language) to JSON decoding library and command-line tool.
"""

from .demal import *